`wildmatch`
-----------

This CLI tool is intended to assist in filtering lists of paths by potentially arbitrary `.gitignore`-like configuration
files. It uses the [`python-pathspec`](https://github.com/cpburnz/python-path-specification) library with `argparse` to 
allow easier use in pipelines and automation.
